use async_httpc::{AsyncHttpc, AsyncHttpcBuilder};
use log::{debug, error, info, trace, warn, LevelFilter, SetLoggerError};
use log4rs::{
    append::console::{ConsoleAppender, Target},
    config::{Appender, Config, Logger, Root},
    encode::pattern::PatternEncoder,
    filter::threshold::ThresholdFilter,
};
use pi_logger::{
    ali_sls::SLSAppender,
    encode_json::JsonEncoder,
    encode_json_str::JsonStrEncoder,
    encode_sls::SLSEncoder,
    http::{http_request, HttpAppender},
    tracing::{init_sls, init_sls_metrics},
};
use pi_serv_lib::{js_log::get_log4rs_config, set_pi_serv_lib_log4rs_handle};
use std::{
    env, thread,
    time::{Duration, Instant},
};
use tracing::span;
use tracing_subscriber::prelude::*;

use crate::FILES_ASYNC_RUNTIME;

fn httpc() -> AsyncHttpc {
    AsyncHttpcBuilder::new()
        .set_default_user_agent("piServHttpClient")
        .add_default_header("Accept", "*/*")
        .add_default_header("Accept-Encoding", "gzip, br")
        .add_default_header("Connection", "keep-alive")
        .enable_cookie(true)
        .enable_gzip(true)
        .enable_auto_referer(true)
        .enable_strict(false)
        .set_redirect_limit(10)
        .set_connect_timeout(5000)
        .set_request_timeout(10000)
        .set_connection_timeout(Some(10000))
        .set_host_connection_limit(10)
        .build()
        .unwrap()
}

// 初始化日志服务
pub fn init() -> Result<(), SetLoggerError> {
    let (config_builder, root) = get_log4rs_config(FILES_ASYNC_RUNTIME.clone()).unwrap();

    let config = config_builder.build(root).unwrap();

    let handle = log4rs::init_config(config)?;
    set_pi_serv_lib_log4rs_handle(handle);
    Ok(())
}

// 初始化trace服务
// pub fn init_trace() {
//     match env::var("TRACING") {
//         Ok(var) => {
//             if var == String::from("true") || var == String::from("TRUE") {
//                 let rt = &TOKIO_RUNTIME;

//                 rt.spawn(async {
//                     let tracer = init_sls();
//                     let metrics = init_sls_metrics();
//                     tracing_subscriber::Registry::default()
//                         .with(
//                             tracing_subscriber::filter::FilterFn::new(|_| true)
//                                 .with_max_level_hint(tracing_subscriber::filter::LevelFilter::INFO),
//                         )
//                         .with(tracing_opentelemetry::layer().with_tracer(tracer))
//                         .with(tracing_opentelemetry::MetricsLayer::new(metrics))
//                         // .with(tracing_subscriber::fmt::layer())
//                         .init();
//                 });
//             }
//         }
//         _ => {}
//     }
// }
